# django-coalesce

Inspired by the awesome .NET [Coalesce](https://intellitect.github.io/Coalesce/) project for accelerated web app development.

### Build

```shell
python3 -m pip install --upgrade build twine
python3 -m build
```
